@@ -1,6 +1,9 @@
 """Module for systematically evaluating different combinations of sklearn pipelines."""
 import functools
 import pickle
+import re
+from copy import deepcopy
+from inspect import getmembers
 from itertools import product
 from pathlib import Path
 from shutil import rmtree
@@ -8,19 +11,51 @@ from typing import Any, Dict, Optional, Sequence, Tuple, Union
 
 import numpy as np
 import pandas as pd
+import sklearn.metrics
 from joblib import Memory
+from numpy.random import RandomState
 from sklearn.base import BaseEstimator, clone
 from sklearn.model_selection import BaseCrossValidator
 from sklearn.pipeline import Pipeline
 from tqdm.auto import tqdm
 
 from biopsykit.classification.model_selection import nested_cv_param_search
-from biopsykit.classification.utils import _PipelineWrapper
+from biopsykit.classification.utils import _PipelineWrapper, merge_nested_dicts
 from biopsykit.utils._datatype_validation_helper import _assert_file_extension
 from biopsykit.utils._types import T, path_t, str_t
 
 __all__ = ["SklearnPipelinePermuter"]
 
+pipeline_step_map = {
+    "pipeline_scaler": "Scaler",
+    "pipeline_reduce_dim": r"\makecell[lc]{Feature\\ Selection}",
+    "pipeline_clf": "Classifier",
+}
+
+metric_map = {
+    "accuracy": r"\makecell{Accuracy [\%]}",
+    "f1": r"\makecell{F1-score [\%]}",
+    "precision": r"\makecell{Precision [\%]}",
+    "recall": r"\makecell{Recall [\%]}",
+    "auc": r"\makecell{AUC [\%]}",
+    "sensitivity": r"\makecell{Sensitivity [\%]}",
+    "specificity": r"\makecell{Specificity [\%]}",
+}
+
+clf_map = {
+    "MinMaxScaler": "Min-Max",
+    "StandardScaler": "Standard",
+    "SelectKBest": "SkB",
+    "RFE": "RFE",
+    "GaussianNB": "NB",
+    "KNeighborsClassifier": "kNN",
+    "DecisionTreeClassifier": "DT",
+    "SVC": "SVM",
+    "RandomForestClassifier": "RF",
+    "MLPClassifier": "MLP",
+    "AdaBoostClassifier": "Ada",
+}
+
 
 class SklearnPipelinePermuter:
     """Class for systematically evaluating different sklearn pipeline combinations."""
@@ -30,6 +65,7 @@ class SklearnPipelinePermuter:
         model_dict: Optional[Dict[str, Dict[str, BaseEstimator]]] = None,
         param_dict: Optional[Dict[str, Optional[Union[Sequence[Dict[str, Any]], Dict[str, Any]]]]] = None,
         hyper_search_dict: Optional[Dict[str, Dict[str, Any]]] = None,
+        random_state: Optional[int] = None,
         **kwargs,
     ):
         """Class for systematically evaluating different sklearn pipeline combinations.
@@ -59,6 +95,9 @@ class SklearnPipelinePermuter:
             Nested dictionary specifying the method for hyperparameter search (e.g., whether to use "grid" for
             grid-search or "random" for randomized-search) for each estimator. By default, "grid-search" is used
             for each estimator unless individually specified otherwise.
+        random_state : int, optional
+            Controls the random seed passed to each estimator and each splitter. By default, no random seed is passed.
+            Set this to an integer for reproducible results across multiple program calls.
 
         Examples
         --------
@@ -152,12 +191,18 @@ class SklearnPipelinePermuter:
 
         self.refit: str = ""
 
+        self.random_state: Optional[RandomState] = None
+
         self._results_set: bool = False
 
         if kwargs.get("score_summary") is not None:
             self.results = kwargs.get("score_summary")
             return
 
+        if model_dict is None and param_dict is None:
+            # create empty instance
+            return
+
         self._check_missing_params(model_dict, param_dict)
 
         if hyper_search_dict is None:
@@ -177,7 +222,10 @@ class SklearnPipelinePermuter:
             if isinstance(v, dict):
                 param_dict[k] = [v]
 
-        self.models = model_dict
+        self.random_state = RandomState(random_state)
+
+        model_dict = deepcopy(model_dict)
+        self.models = self._initialize_models(model_dict)
         self.params = param_dict
         self.model_combinations = model_combinations
 
@@ -268,6 +316,9 @@ class SklearnPipelinePermuter:
         """
         self.results = None
 
+        if len(self.model_combinations) == 0:
+            raise ValueError("No model combinations specified. Please specify at least one model combination.")
+
         kwargs.setdefault("n_jobs", -1)
         kwargs.setdefault("verbose", 1)
         kwargs.setdefault("error_score", "raise")
@@ -325,6 +376,7 @@ class SklearnPipelinePermuter:
                     inner_cv=inner_cv,
                     scoring=scoring,
                     hyper_search_params=hyper_search_params,
+                    random_state=self.random_state,
                     **kwargs,
                 )
 
@@ -435,19 +487,34 @@ class SklearnPipelinePermuter:
         score_summary_mean = self.mean_pipeline_score_results()
         return score_summary.loc[score_summary_mean.index[0]].dropna(how="all", axis=1)
 
-    def metric_summary(self) -> pd.DataFrame:
+    def metric_summary(
+        self, additional_metrics: Optional[str_t] = None, pos_label: Optional[str] = None
+    ) -> pd.DataFrame:
         """Return a summary with all performance metrics for the `best estimator` of each pipeline combination.
 
         The `best estimator` for each pipeline combination is the best estimator that
         :class:`~sklearn.model_selection.GridSearchCV` returns for each outer fold, i.e. the pipeline which yielded
         the highest average test score (over all inner folds).
 
+        Parameters
+        ----------
+        additional_metrics : str or list of str, optional
+            additional metrics to compute. Default: ``None``. Available metrics can be found in sckit-learn's
+            `metrics and scoring <https://scikit-learn.org/stable/modules/model_evaluation.html#scoring-parameter>`_
+            module.
+        pos_label : str, optional
+            positive label for binary classification, must be specified if `additional_metrics` is specified.
+
         Returns
         -------
         :class:`~pandas.DataFrame`
             dataframe with performance metric summary the `best estimator` of each pipeline combination.
 
         """
+        if len(self.param_searches) == 0:
+            raise AttributeError(
+                "No results available because pipelines were not fitted! Call `SklearnPipelinePermuter.fit()` first."
+            )
         list_metric_summary = []
         for param_key, param_value in self.param_searches.items():
             param_dict = {f"pipeline_{key}": val for key, val in param_key}
@@ -481,7 +548,16 @@ class SklearnPipelinePermuter:
             df_metric = df_metric.set_index(list(df_metric.columns)[: len(param_dict)])
             list_metric_summary.append(df_metric)
 
-        return pd.concat(list_metric_summary)
+        metric_summary = pd.concat(list_metric_summary)
+
+        if additional_metrics is not None:
+            if pos_label is None:
+                raise ValueError("pos_label must be specified if additional_metrics are computed!")
+            metric_summary = self.compute_additional_metrics(
+                metric_summary, metrics=additional_metrics, pos_label=pos_label
+            )
+
+        return metric_summary
 
     def export_metric_summary(self, file_path: path_t) -> None:
         """Export performance metric summary as csv file.
@@ -527,6 +603,128 @@ class SklearnPipelinePermuter:
                 missing_params = list(set(model_dict[category].keys()) - set(param_dict.keys()))
                 raise ValueError(f"Some estimators are missing parameters: {missing_params}")
 
+    def metric_summary_to_latex(
+        self,
+        data: Optional[pd.DataFrame] = None,
+        metrics: Sequence[str] = None,
+        pipeline_steps: Optional[Sequence[str]] = None,
+        si_table_format: Optional[str] = None,
+        highlight_best: Optional[Union[str, bool]] = None,
+        **kwargs,
+    ) -> str:
+        """Return a latex table with the performance metrics of the pipeline combinations.
+
+        By default, this function uses the attribute of the ``SklearnPipelinePermuter`` instance.
+        If the ``data`` parameter is set, the function uses the dataframe passed as argument.
+
+        Parameters
+        ----------
+        data : :class:`~pandas.DataFrame`, optional
+            dataframe with performance metrics if custom data should be used or ``None`` to use the attribute of the
+            ``SklearnPipelinePermuter`` instance. Default: ``None``
+        metrics : list of str, optional
+            list of metrics to include in the table or ``None`` to use all available metrics in the dataframe.
+            Default: ``None``
+        pipeline_steps : list of str, optional
+            list of pipeline steps to include in the table index or ``None`` to show all available pipeline steps
+            as table index. Default: ``None``
+        si_table_format : str, optional
+            table format for the ``siunitx`` package or ``None`` to use the default format. Default: ``None``
+        highlight_best : bool or str, optional
+            Whether to highlight the pipeline with the best value in each column or not.
+            *  If ``highlight_best`` is a boolean, the best pipeline is highlighted in each column.
+            *  If ``highlight_best`` is a string, the best pipeline is highlighted in the column with the name
+        **kwargs
+            additional keyword arguments passed to :func:`~pandas.DataFrame.to_latex`
+
+        """
+        kwargs.setdefault("clines", "skip-last;data")
+        kwargs.setdefault("hrules", True)
+        kwargs.setdefault("position", "ht!")
+        kwargs.setdefault("position_float", "centering")
+        kwargs.setdefault("siunitx", True)
+        if si_table_format is None:
+            si_table_format = "table-format = 2.1(2)"
+
+        if data is None:
+            data = self.metric_summary()
+        metric_summary = data.copy()
+
+        if pipeline_steps is None:
+            if isinstance(metric_summary.index, pd.MultiIndex):
+                pipeline_steps = list(metric_summary.index.names)
+            else:
+                pipeline_steps = [metric_summary.index.name]
+
+        if metrics is None:
+            metrics = metric_summary.filter(like="mean_test").columns
+            # extract metric names
+            metrics = [m.split("_")[-1] for m in metrics]
+
+        levels_to_drop = [step for step in metric_summary.index.names if step not in pipeline_steps]
+        metric_summary = metric_summary.droplevel(levels_to_drop)
+        metric_summary = metric_summary.rename(index=clf_map)
+
+        list_metric_summary = []
+        for metric in metrics:
+            list_metric_summary.append(metric_summary.filter(regex=f"(mean|std)_test_{metric}"))
+
+        metric_summary = pd.concat(list_metric_summary, axis=1)
+
+        # convert to percent
+        metric_summary = metric_summary * 100
+        metric_summary_export = metric_summary.copy()
+
+        for metric in metrics:
+            mean_test = f"mean_test_{metric}"
+            std_test = f"std_test_{metric}"
+            m_sd = metric_summary_export.apply(
+                lambda x, m_t=mean_test, std_t=std_test: rf"{x[m_t]:.1f}({x[std_t]:.1f})", axis=1
+            )
+            metric_summary_export = metric_summary_export.assign(**{metric: m_sd})
+        metric_summary_export = metric_summary_export[metrics].copy()
+
+        if isinstance(metric_summary_export.index, pd.MultiIndex):
+            metric_summary_export.index = metric_summary_export.index.rename(pipeline_step_map)
+        metric_summary_export = metric_summary_export.rename(columns=metric_map)
+
+        kwargs.setdefault("column_format", self._format_latex_column_format(metric_summary_export))
+
+        styler = metric_summary_export.style
+        if isinstance(highlight_best, str):
+            max_metric = metric_summary[f"mean_test_{highlight_best}"].idxmax()
+            # get index of max metric
+            max_metric = metric_summary_export.index.get_loc(max_metric)
+            styler = styler.highlight_max(subset=metric_map[highlight_best], props="bfseries: ;")
+            # get maximum of metric_summary
+            # make index bold
+            styler = styler.apply_index(lambda x: np.where(x.index == max_metric, "bfseries: ;", ""))
+        elif isinstance(highlight_best, bool) and highlight_best:
+            styler = styler.highlight_max(props="bfseries: ;")
+
+        metric_summary_tex = styler.to_latex(**kwargs)
+        metric_summary_tex = self._apply_latex_code_correction(metric_summary_tex, si_table_format)
+        return metric_summary_tex
+
+    @staticmethod
+    def _format_latex_column_format(data: pd.DataFrame):
+        column_format = "l" * data.index.nlevels
+        if isinstance(data.columns, pd.MultiIndex):
+            ncols = len(data.columns)
+            ncols_last_level = len(data.columns.get_level_values(-1).unique())
+            column_format += ("S" * ncols_last_level + "|") * (ncols // ncols_last_level)
+            # remove the last "|"
+            column_format = column_format[:-1]
+        else:
+            column_format += "S" * len(data.columns)
+        return column_format
+
+    @staticmethod
+    def _apply_latex_code_correction(table: str, si_table_format: str) -> str:
+        if si_table_format is not None:
+            table = re.sub(r"(\\begin\{tabular\})", r"\\sisetup{" + si_table_format + r"}\n\n\1", table)
+        return table
+
     def to_pickle(self, file_path: path_t) -> None:
         """Export the current instance as a pickle file.
 
@@ -561,3 +759,121 @@ class SklearnPipelinePermuter:
         _assert_file_extension(file_path, ".pkl")
         with open(file_path, "rb") as f:
             return pickle.load(f)
+
+    def merge_permuter_instances(self, permuter: "SklearnPipelinePermuter") -> "SklearnPipelinePermuter":
+        """Merge two :class:`~biopsykit.classification.model_selection.SklearnPipelinePermuter` instances.
+
+        This function first performs a deep copy of the current instance and then merges all attributes of the given
+        ``permuter`` instance with the copy. The ``permuter`` instance passed to this function is not modified.
+
+        Parameters
+        ----------
+        permuter : :class:`~biopsykit.classification.model_selection.SklearnPipelinePermuter`
+            ``SklearnPipelinePermuter`` instance to merge with the current instance
+
+        Returns
+        -------
+        :class:`~biopsykit.classification.model_selection.SklearnPipelinePermuter`
+            merged ``SklearnPipelinePermuter`` instance
+
+        """
+        if self.scoring != permuter.scoring:
+            raise ValueError(
+                f"Cannot merge permuter instances with different scoring functions: "
+                f"{self.scoring} vs. {permuter.scoring}"
+            )
+        if self.refit != permuter.refit:
+            raise ValueError(
+                f"Cannot merge permuter instances with different refit options: {self.refit} vs. {permuter.refit}"
+            )
+
+        # make deep copy of current instance
+        permuter_copy = deepcopy(self)
+
+        # merge model dicts
+        permuter_copy.models = merge_nested_dicts(permuter_copy.models, permuter.models)
+        # merge hyperparameter search dicts
+        permuter_copy.hyper_search_dict = merge_nested_dicts(
+            permuter_copy.hyper_search_dict, permuter.hyper_search_dict
+        )
+        # merge hyperparameter dicts
+        permuter_copy.param_searches = merge_nested_dicts(permuter_copy.param_searches, permuter.param_searches)
+        permuter_copy.params = merge_nested_dicts(permuter_copy.params, permuter.params)
+
+        # merge results dataframes
+        results_concat = pd.concat([permuter_copy.results, permuter.results], axis=0)
+        param_cols = list(results_concat.filter(like="param_").columns)
+        # drop duplicate parameter combinations in results
+        results_concat = results_concat.reset_index("outer_fold").drop_duplicates(subset=["outer_fold"] + param_cols)
+        results_concat = results_concat.set_index("outer_fold", append=True)
+        permuter_copy.results = results_concat
+
+        # merge model combinations
+        permuter_copy.model_combinations += permuter.model_combinations
+        permuter_copy.model_combinations = list(set(permuter_copy.model_combinations))
+
+        return permuter_copy
+
+    @staticmethod
+    def _apply_score(row: pd.Series, score_func, pos_label: str):
+        true_labels_folds = row[0]
+        predicted_labels_folds = row[1]
+        scores = [
+            score_func(true_labels, predicted_labels, pos_label=pos_label)
+            for true_labels, predicted_labels in zip(true_labels_folds, predicted_labels_folds)
+        ]
+        return pd.Series(scores)
+
+    def compute_additional_metrics(self, metric_summary: pd.DataFrame, metrics: str_t, pos_label: str) -> pd.DataFrame:
+        """Compute additional classification metrics.
+
+        Parameters
+        ----------
+        metric_summary : :class:`~pandas.DataFrame`
+            metric summary from :meth:`~biopsykit.classification.model_selection.SklearnPipelinePermuter.metric_summary`
+        metrics : str or list of str
+            metric(s) to compute
+        pos_label : str
+            positive label for binary classification
+
+        Returns
+        -------
+        :class:`~pandas.DataFrame`
+            metric summary with additional metrics computed
+
+        """
+        if isinstance(metrics, str):
+            metrics = [metrics]
+        metric_slice = metric_summary[["true_labels_folds", "predicted_labels_folds"]].copy()
+        metric_out = {}
+        for metric in metrics:
+            score_funcs = dict(getmembers(sklearn.metrics))
+            if metric in score_funcs:
+                score_func = score_funcs[f"{metric}"]
+                metric = metric.replace("_score", "")
+            elif f"{metric}_score" in score_funcs:
+                score_func = score_funcs[f"{metric}_score"]
+            else:
+                raise ValueError(f"Metric '{metric}' not found.")
+            metric_out[metric] = metric_slice.apply(self._apply_score, args=(score_func, pos_label), axis=1)
+        metric_out = pd.concat(metric_out, names=["score", "folds"], axis=1)
+
+        metric_out = metric_out.stack(["score", "folds"])
+        metric_out = metric_out.groupby(metric_out.index.names[:-1]).agg(
+            [("mean", lambda x: np.mean(x)), ("std", lambda x: np.std(x))]
+        )
+
+        metric_out = metric_out.unstack("score").sort_index(axis=1, level="score")
+        metric_out.columns = metric_out.columns.map("_test_".join)
+        metric_summary = metric_summary.join(metric_out)
+        return metric_summary
+
+    def _initialize_models(self, model_dict: Dict[str, Dict[str, Any]]) -> Dict[str, Dict[str, Any]]:
+        if self.random_state is None:
+            return model_dict
+        for k, v in model_dict.items():
+            # add fixed random state to each estimator if it has a random_state parameter
+            for estimator in v.values():
+                if hasattr(estimator, "random_state"):
+                    estimator.random_state = self.random_state
+        return model_dict
