@@ -2,6 +2,8 @@
 from biopsykit.io import carwatch_logs, ecg, eeg, nilspod, saliva, sleep, sleep_analyzer
 from biopsykit.io.io import (
     convert_time_log_datetime,
+    convert_time_log_dict,
+    load_atimelogger_file,
     load_codebook,
     load_long_format_csv,
     load_pandas_dict_excel,
@@ -15,11 +17,13 @@ from biopsykit.io.io import (
 __all__ = [
     "load_long_format_csv",
     "load_time_log",
+    "load_atimelogger_file",
     "load_subject_condition_list",
     "load_questionnaire_data",
     "load_pandas_dict_excel",
     "load_codebook",
     "convert_time_log_datetime",
+    "convert_time_log_dict",
     "write_pandas_dict_excel",
     "write_result_dict",
     "carwatch_logs",
