@@ -153,7 +153,8 @@ def lineplot(
     if show_legend:
         _set_legend_errorbar(**kwargs)
 
-    fig.tight_layout()
+    if kwargs.pop("tight_layout", True):
+        fig.tight_layout()
     return fig, ax
 
 
@@ -227,7 +228,8 @@ def stacked_barchart(data: pd.DataFrame, **kwargs) -> Tuple[plt.Figure, plt.Axes
     if ylabel:
         ax.set_ylabel(ylabel)
 
-    fig.tight_layout()
+    if kwargs.pop("tight_layout", True):
+        fig.tight_layout()
     return fig, ax
 
 
@@ -375,7 +377,8 @@ def feature_boxplot(  # pylint:disable=too-many-branches
             legend_title=legend_title,
         )
     else:
-        fig.tight_layout()
+        if kwargs.pop("tight_layout", True):
+            fig.tight_layout()
     return fig, ax
 
 
@@ -500,7 +503,10 @@ def multi_feature_boxplot(  # pylint:disable=too-many-branches
     handles = None
     labels = None
     for ax, key in zip(axs, features):
-        data_plot = data.reindex(features[key], level=group)
+        reindex_keys = features[key]
+        if isinstance(reindex_keys, str):
+            reindex_keys = [reindex_keys]
+        data_plot = data.reindex(reindex_keys, level=group)
         if data_plot.empty:
             raise ValueError(f"Empty dataframe for '{key}'!")
 
@@ -537,8 +543,8 @@ def multi_feature_boxplot(  # pylint:disable=too-many-branches
             legend_orientation=legend_orientation,
             legend_title=legend_title,
         )
-
-    fig.tight_layout(rect=rect)
+    if kwargs.pop("tight_layout", True):
+        fig.tight_layout(rect=rect)
     return fig, axs
 
 
@@ -578,7 +584,7 @@ def feature_pairplot(
     """
     if abbreviate_names:
         data = data.copy()
-        feature_names = data.columns
+        feature_names = list(data.columns)
         # assign numbers to column names
         data.columns = range(len(data.columns))
         data.columns = data.columns.astype(str)
@@ -722,11 +728,13 @@ def _feature_boxplot_add_legend(fig: plt.Figure, hue: str, handles: Sequence, la
     legend_orientation = kwargs.get("legend_orientation")
     legend_title = kwargs.get("legend_title")
     rect = kwargs.get("rect")
+    tight_layout = kwargs.get("tight_layout")
 
     if hue is not None:
         ncol = len(handles) if legend_orientation == "horizontal" else 1
         fig.legend(handles, labels, loc=legend_loc, fontsize=legend_fontsize, title=legend_title, ncol=ncol)
-    fig.tight_layout(pad=0.5, rect=rect)
+    if tight_layout:
+        fig.tight_layout(pad=0.5, rect=rect)
 
 
 def _multi_feature_boxplot_add_legend(fig: plt.Figure, hue: str, handles: Sequence, labels: Sequence, **kwargs):
@@ -740,7 +748,8 @@ def _multi_feature_boxplot_add_legend(fig: plt.Figure, hue: str, handles: Sequen
         ncol = len(handles) if legend_orientation == "horizontal" else 1
 
         fig.legend(handles, labels, loc=legend_loc, ncol=ncol, fontsize=legend_fontsize, title=legend_title)
-    fig.tight_layout(pad=0.5, rect=rect)
+    if kwargs.pop("tight_layout", True):
+        fig.tight_layout(pad=0.5, rect=rect)
 
 
 def _style_xaxis_multi_feature_boxplot(
