@@ -8,6 +8,20 @@ import pandas as pd
 from biopsykit.utils._datatype_validation_helper import _assert_has_columns, _assert_has_index_levels, _assert_is_dtype
 from biopsykit.utils.datatype_helper import CodebookDataFrame, is_codebook_dataframe
 
+__all__ = [
+    "apply_codebook",
+    "add_space_to_camel",
+    "camel_to_snake",
+    "snake_to_camel",
+    "convert_nan",
+    "int_from_str_idx",
+    "int_from_str_col",
+    "multi_xs",
+    "replace_missing_data",
+    "stack_groups_percent",
+    "wide_to_long",
+]
+
 
 def int_from_str_idx(
     data: pd.DataFrame,
@@ -134,6 +148,43 @@ def camel_to_snake(name: str, lower: Optional[bool] = True):
     return name
 
 
+def snake_to_camel(name: str):
+    """Convert string in "snake_case" to "camelCase".
+
+    Parameters
+    ----------
+    name : str
+        string to convert from snake_case to camelCase
+
+    """
+    return "".join(x.capitalize() or "_" for x in name.split("_"))
+
+
+def add_space_to_camel(name: str) -> str:
+    """Add space to string in "camelCase".
+
+    Parameters
+    ----------
+    name : str
+        string to transform
+
+    Returns
+    -------
+    str
+        string with space added
+
+    Examples
+    --------
+    >>> from biopsykit.utils.dataframe_handling import add_space_to_camel
+    >>> add_space_to_camel("HelloWorld")
+    Hello World
+    >>> add_space_to_camel("ABC")
+    ABC
+
+    """
+    return re.sub(r"((?<=[a-z])[A-Z]|(?<!\A)[A-Z](?=[a-z]))", r" \1", name)
+
+
 def replace_missing_data(
     data: pd.DataFrame,
     target_col: str,
